@@ -4,7 +4,12 @@ from typing import Any, Dict
 import numpy as np
 from torch.utils.data import Dataset
 
-from oml.const import INPUT_TENSORS_KEY, IS_GALLERY_KEY, IS_QUERY_KEY, LABELS_KEY
+from oml.const import (  # noqa
+    INPUT_TENSORS_KEY,
+    IS_GALLERY_KEY,
+    IS_QUERY_KEY,
+    LABELS_KEY,
+)
 from oml.samplers.balance import BalanceSampler  # noqa
 
 
