@@ -1,3 +1,4 @@
+import subprocess
 from pathlib import Path
 
 import pytest
@@ -25,8 +26,18 @@ def find_code_block(file: Path, start_indicator: str, end_indicator: str) -> str
         ("[comment]:vanilla-train-start\n", "[comment]:vanilla-train-end\n"),
         ("[comment]:vanilla-validation-start\n", "[comment]:vanilla-validation-end\n"),
         ("[comment]:lightning-start\n", "[comment]:lightning-end\n"),
+        ("[comment]:lightning-ddp-start\n", "[comment]:lightning-ddp-end\n"),
         ("[comment]:checkpoint-start\n", "[comment]:checkpoint-end\n"),
     ],
 )
 def test_code_blocks_in_readme(start_indicator: str, end_indicator: str) -> None:
-    exec(find_code_block(PROJECT_ROOT / "README.md", start_indicator, end_indicator))
+    code = find_code_block(PROJECT_ROOT / "README.md", start_indicator, end_indicator)
+    tmp_fname = "tmp.py"
+
+    with open(tmp_fname, "w") as f:
+        f.write(code)
+
+    try:
+        subprocess.run(f"python {tmp_fname}", check=True, shell=True)
+    finally:
+        Path(tmp_fname).unlink()
